@@ -1,5 +1,7 @@
 from .contour import Contour
 from .hints import (RawContour,
+                    RawMultisegment,
                     RawSegment,
                     Vertices)
+from .multisegment import Multisegment
 from .segment import Segment
