@@ -23,11 +23,14 @@ from gon.compound import (Compound,
                           Relation)
 from gon.degenerate import EMPTY
 from gon.discrete import (Multipoint,
-                          _robust_divide)
+                          _robust_divide,
+                          _rotate_points_around_origin,
+                          _rotate_translate_points)
 from gon.geometry import Geometry
 from gon.hints import Coordinate
 from gon.primitive import (Point,
-                           RawPoint)
+                           RawPoint,
+                           _point_to_step)
 from . import vertices as _vertices
 from .hints import (RawContour,
                     RawMultisegment,
@@ -194,11 +197,13 @@ class Contour(Indexable, Linear):
         Returns hash value of the contour.
 
         Time complexity:
-            ``O(len(self.vertices))``
+            ``O(vertices_count)``
         Memory complexity:
             ``O(1)`` if contour is counterclockwise
             and starts from the bottom leftmost vertex,
-            ``O(len(self.vertices))`` otherwise
+            ``O(vertices_count)`` otherwise
+
+        where ``vertices_count = len(self.vertices)``.
 
         >>> contour = Contour.from_raw([(0, 0), (1, 0), (0, 1)])
         >>> hash(contour) == hash(contour)
@@ -208,7 +213,7 @@ class Contour(Indexable, Linear):
         return hash(vertices
                     if (to_orientation(vertices[0], vertices[- 1], vertices[1])
                         is Orientation.COUNTERCLOCKWISE)
-                    else _vertices.rotate(vertices))
+                    else _vertices.rotate_positions(vertices))
 
     def __le__(self, other: Compound) -> bool:
         """
@@ -558,7 +563,34 @@ class Contour(Indexable, Linear):
         >>> contour.reverse().reverse() == contour
         True
         """
-        return Contour(_vertices.rotate(self._vertices))
+        return Contour(_vertices.rotate_positions(self._vertices))
+
+    def rotate(self,
+               cosine: Coordinate,
+               sine: Coordinate,
+               point: Optional[Point] = None) -> 'Contour':
+        """
+        Rotates the contour by given cosine & sine around given point.
+
+        Time complexity:
+            ``O(vertices_count)``
+        Memory complexity:
+            ``O(vertices_count)``
+
+        where ``vertices_count = len(self.vertices)``.
+
+        >>> contour = Contour.from_raw([(0, 0), (1, 0), (0, 1)])
+        >>> contour.rotate(1, 0) == contour
+        True
+        >>> (contour.rotate(0, 1, Point(1, 1))
+        ...  == Contour.from_raw([(2, 0), (2, 1), (1, 0)]))
+        True
+        """
+        return (rotate_contour_around_origin(self, cosine, sine)
+                if point is None
+                else _rotate_translate_contour(self, cosine, sine,
+                                               *_point_to_step(point, cosine,
+                                                               sine)))
 
     def scale(self,
               factor_x: Coordinate,
@@ -582,10 +614,9 @@ class Contour(Indexable, Linear):
         """
         if factor_y is None:
             factor_y = factor_x
-        return (Contour(_vertices.scale(self._vertices, factor_x, factor_y))
+        return (_scale_contour(self, factor_x, factor_y)
                 if factor_x and factor_y
-                else _vertices.scale_degenerate(self._vertices, factor_x,
-                                                factor_y))
+                else _scale_contour_degenerate(self, factor_x, factor_y))
 
     def to_clockwise(self) -> 'Contour':
         """
@@ -719,3 +750,31 @@ def raw_locate_point(raw_contour: RawContour, raw_point: RawPoint) -> Location:
     return (Location.BOUNDARY
             if point_in_contour(raw_point, raw_contour)
             else Location.EXTERIOR)
+
+
+def rotate_contour_around_origin(contour: Contour,
+                                 cosine: Coordinate,
+                                 sine: Coordinate) -> Contour:
+    return Contour(_rotate_points_around_origin(contour._vertices, cosine,
+                                                sine))
+
+
+def _rotate_translate_contour(contour: Contour,
+                              cosine: Coordinate,
+                              sine: Coordinate,
+                              step_x: Coordinate,
+                              step_y: Coordinate) -> Contour:
+    return Contour(_rotate_translate_points(contour._vertices, cosine, sine,
+                                            step_x, step_y))
+
+
+def _scale_contour(contour: Contour,
+                   factor_x: Coordinate,
+                   factor_y: Coordinate) -> Contour:
+    return Contour(_vertices.scale(contour._vertices, factor_x, factor_y))
+
+
+def _scale_contour_degenerate(contour: Contour,
+                              factor_x: Coordinate,
+                              factor_y: Coordinate) -> Compound:
+    return _vertices.scale_degenerate(contour._vertices, factor_x, factor_y)
