@@ -29,12 +29,15 @@ from gon.geometry import Geometry
 from gon.hints import Coordinate
 from gon.primitive import (Point,
                            RawPoint,
+                           _point_to_step,
                            _scale_point,
                            _scale_raw_point)
 from .hints import (RawMultisegment,
                     RawSegment)
 from .segment import (Segment,
-                      _scale_segment)
+                      _rotate_translate_segment,
+                      _scale_segment,
+                      rotate_segment_around_origin)
 from .utils import (from_raw_mix_components,
                     from_raw_multisegment,
                     relate_multipoint_to_linear_compound,
@@ -535,6 +538,38 @@ class Multisegment(Indexable, Linear):
                             if isinstance(other, Multisegment)
                             else other.relate(self).complement)))
 
+    def rotate(self,
+               cosine: Coordinate,
+               sine: Coordinate,
+               point: Optional[Point] = None) -> 'Multisegment':
+        """
+        Rotates the multisegment by given cosine & sine around given point.
+
+        Time complexity:
+            ``O(segments_count)``
+        Memory complexity:
+            ``O(segments_count)``
+
+        where ``segments_count = len(self.segments)``.
+
+        >>> multisegment = Multisegment.from_raw([((0, 0), (1, 0)),
+        ...                                       ((0, 1), (1, 1))])
+        >>> multisegment.rotate(1, 0) == multisegment
+        True
+        >>> (multisegment.rotate(0, 1, Point(1, 1))
+        ...  == Multisegment.from_raw([((2, 0), (2, 1)), ((1, 0), (1, 1))]))
+        True
+        """
+        return (Multisegment(*[rotate_segment_around_origin(segment, cosine,
+                                                            sine)
+                               for segment in self._segments])
+                if point is None
+                else Multisegment(
+                *[_rotate_translate_segment(segment, cosine, sine,
+                                            *_point_to_step(point, cosine,
+                                                            sine))
+                  for segment in self._segments]))
+
     def scale(self,
               factor_x: Coordinate,
               factor_y: Optional[Coordinate] = None) -> Compound:
