@@ -42,10 +42,15 @@ from gon.linear import (Contour,
                         RawMultisegment,
                         Segment,
                         vertices)
+from gon.linear.contour import (_rotate_translate_contour,
+                                _scale_contour,
+                                _scale_contour_degenerate,
+                                rotate_contour_around_origin)
 from gon.linear.utils import (from_raw_multisegment,
                               to_pairs_chain)
 from gon.primitive import (Point,
-                           RawPoint)
+                           RawPoint,
+                           _point_to_step)
 from .hints import (RawMultipolygon,
                     RawPolygon)
 from .utils import (from_raw_mix_components,
@@ -631,7 +636,7 @@ class Polygon(Indexable, Shaped):
         >>> polygon.locate(Point(7, 0)) is Location.EXTERIOR
         True
         """
-        return isinstance(point, Point) and self._raw_locate(point.raw())
+        return self._raw_locate(point.raw())
 
     def raw(self) -> RawPolygon:
         """
@@ -683,6 +688,36 @@ class Polygon(Indexable, Shaped):
                                   if isinstance(other, Polygon)
                                   else other.relate(self).complement))))
 
+    def rotate(self,
+               cosine: Coordinate,
+               sine: Coordinate,
+               point: Optional[Point] = None) -> 'Polygon':
+        """
+        Rotates the polygon by given cosine & sine around given point.
+
+        Time complexity:
+            ``O(vertices_count)``
+        Memory complexity:
+            ``O(vertices_count)``
+
+        where ``vertices_count = len(self.border.vertices)\
+ + sum(len(hole.vertices) for hole in self.holes)``.
+
+        >>> polygon = Polygon.from_raw(([(0, 0), (6, 0), (6, 6), (0, 6)],
+        ...                             [[(2, 2), (2, 4), (4, 4), (4, 2)]]))
+        >>> polygon.rotate(1, 0) == polygon
+        True
+        >>> (polygon.rotate(0, 1, Point(1, 1))
+        ...  == Polygon.from_raw(([(2, 0), (2, 6), (-4, 6), (-4, 0)],
+        ...                       [[(0, 2), (-2, 2), (-2, 4), (0, 4)]])))
+        True
+        """
+        return (rotate_polygon_around_origin(self, cosine, sine)
+                if point is None
+                else _rotate_translate_polygon(self, cosine, sine,
+                                               *_point_to_step(point, cosine,
+                                                               sine)))
+
     def scale(self,
               factor_x: Coordinate,
               factor_y: Optional[Coordinate] = None) -> 'Polygon':
@@ -710,8 +745,8 @@ class Polygon(Indexable, Shaped):
             factor_y = factor_x
         return (_scale_polygon(self, factor_x, factor_y)
                 if factor_x and factor_y
-                else vertices.scale_degenerate(self._border._vertices,
-                                               factor_x, factor_y))
+                else _scale_contour_degenerate(self._border, factor_x,
+                                               factor_y))
 
     def translate(self, step_x: Coordinate, step_y: Coordinate) -> 'Polygon':
         """
@@ -892,10 +927,28 @@ def _raw_contour_to_centroid_components(contour: RawContour
 def _scale_polygon(polygon: Polygon,
                    factor_x: Coordinate,
                    factor_y: Coordinate) -> Polygon:
-    return Polygon(Contour(vertices.scale(polygon._border._vertices,
-                                          factor_x, factor_y)),
-                   [Contour(vertices.scale(hole._vertices, factor_x,
-                                           factor_y))
+    return Polygon(_scale_contour(polygon._border, factor_x, factor_y),
+                   [_scale_contour(hole, factor_x, factor_y)
+                    for hole in polygon._holes])
+
+
+def rotate_polygon_around_origin(polygon: Polygon,
+                                 cosine: Coordinate,
+                                 sine: Coordinate) -> Polygon:
+    return Polygon(rotate_contour_around_origin(polygon._border, cosine, sine),
+                   [rotate_contour_around_origin(hole, cosine, sine)
+                    for hole in polygon._holes])
+
+
+def _rotate_translate_polygon(polygon: Polygon,
+                              cosine: Coordinate,
+                              sine: Coordinate,
+                              step_x: Coordinate,
+                              step_y: Coordinate) -> Polygon:
+    return Polygon(_rotate_translate_contour(polygon._border, cosine, sine,
+                                             step_x, step_y),
+                   [_rotate_translate_contour(hole, cosine, sine, step_x,
+                                              step_y)
                     for hole in polygon._holes])
 
 
